==> ja-WiKicker-0.23.tbz: lib/perl5/site_perl/5.8.5/WiKicker/WikiCGI/View/HTML/Success.pm <==
#
# WiKicker
#
#  Success.pm
#
#
# Copyright (C) 2003,2004 WATANABE Yoshimasa <naney@naney.org>
#
# This file is part of the WiKicker.
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 2 of the License, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
# more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc., 59
# Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
#
# $Id: Success.pm,v 1.3 2004/05/01 07:06:08 naney Exp $
#
#

package WiKicker::WikiCGI::View::HTML::Success;

use 5.005;
use strict;

use WiKicker::WikiCGI::View::HTML;
#use WiKicker::PageName;

use vars qw(@ISA);
@ISA = qw(WiKicker::WikiCGI::View::HTML);

sub make_html_body {
  my $self = shift;

  my $response = $self->response;

  my $success_type = $self->request->attribute('successtype') || '';
  if ($success_type eq 'delete') {
    $response->add_content('done');
    return;
  }

  #my $content = $self->make_html_fragment("done: " . WiKicker::PageName::armor_name($request->name), 1);
  #$response->add_content($content);
  $response->add_content(qq(<p>done: ));
  $response->add_content($self->link_maker->make_page_name_link($self->request->name, '', '', 0));
  $response->add_content(qq(</p>\n));
}

1;

==> ja-WiKicker-0.26.tbz: lib/perl5/site_perl/5.8.9/WiKicker/WikiCGI/View/HTML/Success.pm <==
#
# WiKicker
#
#  Success.pm
#
#
# Copyright (C) 2003,2004 WATANABE Yoshimasa <naney@naney.org>
#
# This file is part of the WiKicker.
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 2 of the License, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
# more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc., 59
# Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
#
# $Id: Success.pm,v 1.4 2004/08/03 12:55:52 naney Exp $
#
#

package WiKicker::WikiCGI::View::HTML::Success;

use 5.005;
use strict;

use WiKicker::WikiCGI::View::HTML;
#use WiKicker::PageName;

use vars qw(@ISA);
@ISA = qw(WiKicker::WikiCGI::View::HTML);

sub make_html_body {
  my $self = shift;

  my $response = $self->response;

  my $success_type = $self->request->attribute('successtype') || '';
  if ($success_type eq 'delete') {
    $response->add_content('done');
    return;
  }

  #my $content = $self->make_html_fragment("done: " . WiKicker::PageName::armor_name($request->name), 1);
  #$response->add_content($content);
  $response->add_content(q(<p>done: ));
  $response->add_content($self->link_maker->make_page_name_link($self->request->name, '', '', 0));
  $response->add_content(qq(</p>\n));
}

1;
